@@ -2,12 +2,12 @@
 # -*- encoding: utf-8 -*-
 
 from rayvision_api import RayvisionAPI
-
+from cloghandler import ConcurrentRotatingFileHandler
 render_para = {
     "domain": "task.renderbus.com",  # 用戶不需要修改
     "platform": "2",
-    "access_id": "xxxxx",  # 用户自行修改(必填)
-    "access_key": "xxxxx",  # 用户自行修改(必填)
+    "access_id": "xxxx",  # 用户自行修改(必填)
+    "access_key": "xxxx",  # 用户自行修改(必填)
 }
 
 api = RayvisionAPI(access_id=render_para['access_id'],
@@ -16,7 +16,7 @@ api = RayvisionAPI(access_id=render_para['access_id'],
                    platform=render_para['platform'])
 
 
-print("======= 获取平台列表 =============")
+# print("======= 获取平台列表 =============")
 platform = api.query.platforms()
 print(platform)
 #
